@@ -14,8 +14,7 @@ Usage::
     ```
 """
 import sys
-from datetime import datetime
-from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -31,9 +30,9 @@ from .type_defs import (
     GetPipelineDefinitionOutputTypeDef,
     InstanceIdentityTypeDef,
     ListPipelinesOutputTypeDef,
-    ParameterObjectTypeDef,
+    ParameterObjectUnionTypeDef,
     ParameterValueTypeDef,
-    PipelineObjectTypeDef,
+    PipelineObjectUnionTypeDef,
     PollForTaskOutputTypeDef,
     PutPipelineDefinitionOutputTypeDef,
     QueryObjectsOutputTypeDef,
@@ -41,6 +40,7 @@ from .type_defs import (
     ReportTaskProgressOutputTypeDef,
     ReportTaskRunnerHeartbeatOutputTypeDef,
     TagTypeDef,
+    TimestampTypeDef,
     ValidatePipelineDefinitionOutputTypeDef,
 )
 
@@ -92,7 +92,7 @@ class DataPipelineClient(BaseClient):
         *,
         pipelineId: str,
         parameterValues: Sequence[ParameterValueTypeDef] = ...,
-        startTimestamp: Union[datetime, str] = ...
+        startTimestamp: TimestampTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Validates the specified pipeline and starts processing pipeline tasks.
@@ -237,8 +237,8 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        pipelineObjects: Sequence[PipelineObjectTypeDef],
-        parameterObjects: Sequence[ParameterObjectTypeDef] = ...,
+        pipelineObjects: Sequence[PipelineObjectUnionTypeDef],
+        parameterObjects: Sequence[ParameterObjectUnionTypeDef] = ...,
         parameterValues: Sequence[ParameterValueTypeDef] = ...
     ) -> PutPipelineDefinitionOutputTypeDef:
         """
@@ -327,8 +327,8 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        pipelineObjects: Sequence[PipelineObjectTypeDef],
-        parameterObjects: Sequence[ParameterObjectTypeDef] = ...,
+        pipelineObjects: Sequence[PipelineObjectUnionTypeDef],
+        parameterObjects: Sequence[ParameterObjectUnionTypeDef] = ...,
         parameterValues: Sequence[ParameterValueTypeDef] = ...
     ) -> ValidatePipelineDefinitionOutputTypeDef:
         """
