@@ -8,7 +8,7 @@ Usage::
     ```python
     from mypy_boto3_datapipeline.type_defs import ParameterValueTypeDef
 
-    data: ParameterValueTypeDef = {...}
+    data: ParameterValueTypeDef = ...
     ```
 """
 import sys
@@ -25,6 +25,7 @@ else:
 
 __all__ = (
     "ParameterValueTypeDef",
+    "TimestampTypeDef",
     "TagTypeDef",
     "ResponseMetadataTypeDef",
     "DeactivatePipelineInputRequestTypeDef",
@@ -58,24 +59,28 @@ __all__ = (
     "DescribeObjectsInputDescribeObjectsPaginateTypeDef",
     "ListPipelinesInputListPipelinesPaginateTypeDef",
     "PipelineDescriptionTypeDef",
+    "PipelineObjectOutputTypeDef",
     "PipelineObjectTypeDef",
     "ReportTaskProgressInputRequestTypeDef",
     "PollForTaskInputRequestTypeDef",
     "ListPipelinesOutputTypeDef",
     "SelectorTypeDef",
+    "ParameterObjectOutputTypeDef",
     "ParameterObjectTypeDef",
     "PutPipelineDefinitionOutputTypeDef",
     "ValidatePipelineDefinitionOutputTypeDef",
     "DescribePipelinesOutputTypeDef",
     "DescribeObjectsOutputTypeDef",
     "TaskObjectTypeDef",
+    "PipelineObjectUnionTypeDef",
     "QueryTypeDef",
     "GetPipelineDefinitionOutputTypeDef",
-    "PutPipelineDefinitionInputRequestTypeDef",
-    "ValidatePipelineDefinitionInputRequestTypeDef",
+    "ParameterObjectUnionTypeDef",
     "PollForTaskOutputTypeDef",
     "QueryObjectsInputQueryObjectsPaginateTypeDef",
     "QueryObjectsInputRequestTypeDef",
+    "PutPipelineDefinitionInputRequestTypeDef",
+    "ValidatePipelineDefinitionInputRequestTypeDef",
 )
 
 ParameterValueTypeDef = TypedDict(
@@ -86,6 +91,7 @@ ParameterValueTypeDef = TypedDict(
     },
 )
 
+TimestampTypeDef = Union[datetime, str]
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -359,7 +365,7 @@ _OptionalActivatePipelineInputRequestTypeDef = TypedDict(
     "_OptionalActivatePipelineInputRequestTypeDef",
     {
         "parameterValues": Sequence[ParameterValueTypeDef],
-        "startTimestamp": Union[datetime, str],
+        "startTimestamp": TimestampTypeDef,
     },
     total=False,
 )
@@ -507,12 +513,21 @@ class PipelineDescriptionTypeDef(
     pass
 
 
+PipelineObjectOutputTypeDef = TypedDict(
+    "PipelineObjectOutputTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "fields": List[FieldTypeDef],
+    },
+)
+
 PipelineObjectTypeDef = TypedDict(
     "PipelineObjectTypeDef",
     {
         "id": str,
         "name": str,
-        "fields": List[FieldTypeDef],
+        "fields": Sequence[FieldTypeDef],
     },
 )
 
@@ -578,11 +593,19 @@ SelectorTypeDef = TypedDict(
     total=False,
 )
 
+ParameterObjectOutputTypeDef = TypedDict(
+    "ParameterObjectOutputTypeDef",
+    {
+        "id": str,
+        "attributes": List[ParameterAttributeTypeDef],
+    },
+)
+
 ParameterObjectTypeDef = TypedDict(
     "ParameterObjectTypeDef",
     {
         "id": str,
-        "attributes": List[ParameterAttributeTypeDef],
+        "attributes": Sequence[ParameterAttributeTypeDef],
     },
 )
 
@@ -617,7 +640,7 @@ DescribePipelinesOutputTypeDef = TypedDict(
 DescribeObjectsOutputTypeDef = TypedDict(
     "DescribeObjectsOutputTypeDef",
     {
-        "pipelineObjects": List[PipelineObjectTypeDef],
+        "pipelineObjects": List[PipelineObjectOutputTypeDef],
         "marker": str,
         "hasMoreResults": bool,
         "ResponseMetadata": ResponseMetadataTypeDef,
@@ -630,11 +653,12 @@ TaskObjectTypeDef = TypedDict(
         "taskId": str,
         "pipelineId": str,
         "attemptId": str,
-        "objects": Dict[str, PipelineObjectTypeDef],
+        "objects": Dict[str, PipelineObjectOutputTypeDef],
     },
     total=False,
 )
 
+PipelineObjectUnionTypeDef = Union[PipelineObjectTypeDef, PipelineObjectOutputTypeDef]
 QueryTypeDef = TypedDict(
     "QueryTypeDef",
     {
@@ -646,61 +670,14 @@ QueryTypeDef = TypedDict(
 GetPipelineDefinitionOutputTypeDef = TypedDict(
     "GetPipelineDefinitionOutputTypeDef",
     {
-        "pipelineObjects": List[PipelineObjectTypeDef],
-        "parameterObjects": List[ParameterObjectTypeDef],
+        "pipelineObjects": List[PipelineObjectOutputTypeDef],
+        "parameterObjects": List[ParameterObjectOutputTypeDef],
         "parameterValues": List[ParameterValueTypeDef],
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-_RequiredPutPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_RequiredPutPipelineDefinitionInputRequestTypeDef",
-    {
-        "pipelineId": str,
-        "pipelineObjects": Sequence[PipelineObjectTypeDef],
-    },
-)
-_OptionalPutPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_OptionalPutPipelineDefinitionInputRequestTypeDef",
-    {
-        "parameterObjects": Sequence[ParameterObjectTypeDef],
-        "parameterValues": Sequence[ParameterValueTypeDef],
-    },
-    total=False,
-)
-
-
-class PutPipelineDefinitionInputRequestTypeDef(
-    _RequiredPutPipelineDefinitionInputRequestTypeDef,
-    _OptionalPutPipelineDefinitionInputRequestTypeDef,
-):
-    pass
-
-
-_RequiredValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_RequiredValidatePipelineDefinitionInputRequestTypeDef",
-    {
-        "pipelineId": str,
-        "pipelineObjects": Sequence[PipelineObjectTypeDef],
-    },
-)
-_OptionalValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_OptionalValidatePipelineDefinitionInputRequestTypeDef",
-    {
-        "parameterObjects": Sequence[ParameterObjectTypeDef],
-        "parameterValues": Sequence[ParameterValueTypeDef],
-    },
-    total=False,
-)
-
-
-class ValidatePipelineDefinitionInputRequestTypeDef(
-    _RequiredValidatePipelineDefinitionInputRequestTypeDef,
-    _OptionalValidatePipelineDefinitionInputRequestTypeDef,
-):
-    pass
-
-
+ParameterObjectUnionTypeDef = Union[ParameterObjectTypeDef, ParameterObjectOutputTypeDef]
 PollForTaskOutputTypeDef = TypedDict(
     "PollForTaskOutputTypeDef",
     {
@@ -755,3 +732,51 @@ class QueryObjectsInputRequestTypeDef(
     _RequiredQueryObjectsInputRequestTypeDef, _OptionalQueryObjectsInputRequestTypeDef
 ):
     pass
+
+
+_RequiredPutPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_RequiredPutPipelineDefinitionInputRequestTypeDef",
+    {
+        "pipelineId": str,
+        "pipelineObjects": Sequence[PipelineObjectUnionTypeDef],
+    },
+)
+_OptionalPutPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_OptionalPutPipelineDefinitionInputRequestTypeDef",
+    {
+        "parameterObjects": Sequence[ParameterObjectUnionTypeDef],
+        "parameterValues": Sequence[ParameterValueTypeDef],
+    },
+    total=False,
+)
+
+
+class PutPipelineDefinitionInputRequestTypeDef(
+    _RequiredPutPipelineDefinitionInputRequestTypeDef,
+    _OptionalPutPipelineDefinitionInputRequestTypeDef,
+):
+    pass
+
+
+_RequiredValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_RequiredValidatePipelineDefinitionInputRequestTypeDef",
+    {
+        "pipelineId": str,
+        "pipelineObjects": Sequence[PipelineObjectUnionTypeDef],
+    },
+)
+_OptionalValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_OptionalValidatePipelineDefinitionInputRequestTypeDef",
+    {
+        "parameterObjects": Sequence[ParameterObjectUnionTypeDef],
+        "parameterValues": Sequence[ParameterValueTypeDef],
+    },
+    total=False,
+)
+
+
+class ValidatePipelineDefinitionInputRequestTypeDef(
+    _RequiredValidatePipelineDefinitionInputRequestTypeDef,
+    _OptionalValidatePipelineDefinitionInputRequestTypeDef,
+):
+    pass
